@@ -2,7 +2,7 @@ package Dist::Zilla::PluginBundle::Author::GSG;
 
 # ABSTRACT: Grant Street Group CPAN dists
 use version;
-our $VERSION = 'v0.1.4'; # VERSION
+our $VERSION = 'v0.1.5'; # VERSION
 
 use Carp;
 use Git::Wrapper;
@@ -247,7 +247,8 @@ before 'provide_version' => sub {
         Carp::croak "Invalid version '$ENV{V}' in \$ENV{V}"
             if @v > 3 or grep /\D/, @v;
 
-        $ENV{V} = sprintf "v%d.%d.%d", @v, 0, 0, 0;
+        # perl v5.22+ complain about too many arguments to printf
+        $ENV{V} = sprintf "v%d.%d.%d", (@v, 0, 0, 0)[0..2];
     }
 };
 
@@ -266,7 +267,7 @@ Dist::Zilla::PluginBundle::Author::GSG - Grant Street Group CPAN dists
 
 =head1 VERSION
 
-version v0.1.4
+version v0.1.5
 
 =head1 SYNOPSIS
 
@@ -317,7 +318,7 @@ Some of which comes from L<Dist::Zilla::Plugin::Author::GSG>.
     [ExecDir]
     dir = script    # in addition to bin/ for StaticInstall compatibility
 
-    [Pod::Weaver]
+    [PodWeaver]
     replacer = replace_with_comment
     post_code_replacer = replace_with_nothing
     config_plugin = [ @Default, Contributors ]
@@ -486,7 +487,7 @@ might look like this:
         carton exec perl -Ilib -MFile::ShareDir=dist_dir -e \
             'print eval { dist_dir("Dist-Zilla-PluginBundle-Author-GSG") } || "share"' )
 
-    include $(SHARE_DIR)/Makefile
+    include $(SHARE_DIR)/Makefile.inc
 
     # Copy the SHARE_DIR Makefile over this one:
     # Making it .PHONY will force it to copy even if this one is newer.
